@@ -1,6 +1,6 @@
 import logging
 from ssl import SSLContext
-from typing import Optional, Union, Dict, Any
+from typing import Optional, Union, Dict, Any, List
 
 import aiohttp
 from aiohttp import FormData, BasicAuth
@@ -19,6 +19,9 @@ from .internal_utils import (
 )
 from ..proxy_env_variable_loader import load_http_proxy_from_env
 
+from slack_sdk.http_retry.builtin_async_handlers import async_default_handlers
+from slack_sdk.http_retry.handler import RetryHandler
+
 
 class AsyncBaseClient:
     BASE_URL = "https://www.slack.com/api/"
@@ -38,6 +41,7 @@ class AsyncBaseClient:
         # for Org-Wide App installation
         team_id: Optional[str] = None,
         logger: Optional[logging.Logger] = None,
+        retry_handlers: Optional[List[RetryHandler]] = None,
     ):
         self.token = None if token is None else token.strip()
         self.base_url = base_url
@@ -55,6 +59,9 @@ class AsyncBaseClient:
         if team_id is not None:
             self.default_params["team_id"] = team_id
         self._logger = logger if logger is not None else logging.getLogger(__name__)
+        self.retry_handlers = (
+            retry_handlers if retry_handlers is not None else async_default_handlers()
+        )
 
         if self.proxy is None or len(self.proxy.strip()) == 0:
             env_variable = load_http_proxy_from_env(self._logger)
@@ -192,4 +199,5 @@ class AsyncBaseClient:
             http_verb=http_verb,
             api_url=api_url,
             req_args=req_args,
+            retry_handlers=self.retry_handlers,
         )
